@@ -113,7 +113,7 @@ class HTTPClient(object):
 
         # logging setup
         self.debug_log = debug
-        if self.debug_log:
+        if self.debug_log and not _logger.handlers:
             ch = logging.StreamHandler()
             _logger.setLevel(logging.DEBUG)
             _logger.addHandler(ch)
@@ -351,27 +351,23 @@ class HTTPClient(object):
             request_kwargs.setdefault('timeout', self.timeout)
 
         self.http_log_req((url, method,), request_kwargs)
-        resp = requests.request(
-            method,
-            url,
-            verify=self.verify_cert,
-            **request_kwargs)
+
+        try:
+            resp = requests.request(
+                method,
+                url,
+                verify=self.verify_cert,
+                **request_kwargs)
+        except requests.ConnectionError:
+            msg = 'Unable to establish connection to %s' % url
+            raise exceptions.ClientException(msg)
 
         self.http_log_resp(resp)
 
-        if resp.status_code >= 400:
-            _logger.debug(
-                "Request returned failure status: %s",
-                resp.status_code)
-            raise exceptions.from_response(resp, resp.text)
-        elif resp.status_code in (301, 302, 305):
-            # Redirected. Reissue the request to the new location.
-            return self.request(resp.headers['location'], method, **kwargs)
-
         if resp.text:
             try:
                 body = json.loads(resp.text)
-            except ValueError:
+            except (ValueError, TypeError):
                 body = None
                 _logger.debug("Could not decode JSON from body: %s"
                               % resp.text)
@@ -379,6 +375,15 @@ class HTTPClient(object):
             _logger.debug("No body was returned.")
             body = None
 
+        if resp.status_code >= 400:
+            _logger.debug(
+                "Request returned failure status: %s",
+                resp.status_code)
+            raise exceptions.from_response(resp, body or resp.text)
+        elif resp.status_code in (301, 302, 305):
+            # Redirected. Reissue the request to the new location.
+            return self.request(resp.headers['location'], method, **kwargs)
+
         return resp, body
 
     def _cs_request(self, url, method, **kwargs):
